@@ -1,3 +1,26 @@
+/*
+ * This file is part of phonelink
+ *
+ * Copyright (C) 2008 FLL.
+ *
+ *
+ * This software is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA
+ *
+ */
+
 #include <string.h>
 #include <locale.h>
 #include <unistd.h>
@@ -15,6 +38,8 @@
 
 #include <config.h>
 
+#include "phonelink.h"
+
 #ifdef GNOKII_GCONF
 #include "gnokii-gconf.h"
 #endif
@@ -23,6 +48,8 @@
 #include "client-contactinfos-dbus.h"
 #include "marshall.h"
 
+#include "dbussignal.h"
+
 #if HILDON == 1
 #include <hildon/hildon.h>
 #else
@@ -79,13 +106,6 @@ void dialNumberFromSearch(UIComponents * uic, gboolean gsm);
 void dialNumber(UIComponents * uic, gchar *number);
 static void sendSMS (gchar *number, gchar *text);
 
-/* D-BUS service definitions */
-#define APPLICATION_DBUS_SERVICE "phonelink"
-
-#define GCONF_TRANSFORM_PLUS_KEY "/apps/phonelink/TransformPlusIntoDoubleZero"
-#define GCONF_NOTIFY_CALL_KEY "/apps/phonelink/NotifyMeForIncomingCall"
-#define GCONF_NOTIFY_SMS_KEY "/apps/phonelink/NotifyMeForSMSReception"
-
 static void  quit_event( UIComponents *uic, guint callback_action, GtkWidget *menu_item	) {
 	GConfClient *gconf_client = NULL;
 
@@ -122,6 +142,14 @@ gboolean pollPhone_cb(UIComponents *uic) {
 	return FALSE;
 }
 
+
+gboolean sendDBus_cb(gn_call_info *call_info) {
+
+	sendDBusIncomingCallSignal(call_info->number, call_info->name); 
+	return FALSE;
+}
+
+
 /* callback to check availability of contactinfos service */
 gboolean checkAvailability_cb(UIComponents *uic) {
 	
@@ -304,6 +332,8 @@ void notify_call(gn_call_status call_status, gn_call_info *call_info, struct gn_
 	
 	uic->callDetected = call_info->call_id;
 	
+	g_idle_add ((GSourceFunc)sendDBus_cb, call_info);
+	
 	descr = g_strdup_printf(_("Incoming Call\nnumber: %s\nname: %s"), call_info->number, call_info->name);
 	note = hildon_note_new_confirmation_add_buttons(NULL, descr, _("Answer"), GTK_RESPONSE_ACCEPT, _("Hang Up"), GTK_RESPONSE_REJECT, _("Ignore"), GTK_RESPONSE_CANCEL, NULL);
 	g_free(descr);
